/**
 * The CBC-MAC encryption module for NRF microcontrollers.
 *
 * @author  Ehsan Tofigh
 * @project lcx
 * @file    include/libcortex/ccm.h
 * @license
 */

#pragma once

/* Use C linkage to avoid name mangling in C++: */
#ifdef __cplusplus
extern "C" {
#endif

#include "mdk/ccm.h"

#include <stdbool.h>
#include <stddef.h>
#include <stdint.h>

/**
 * Initialise the CCM module.
 *
 * @param[in] datarate Radio's datarate for synchronised operation.
 * @param[in] key      Pointer to the 16 byte AES key.
 * @param[in] iv       Pointer to the 8 byte initialisation vector.
 *
 * @retval true  Successfully initialised the CCM module.
 * @retval false Failed to initialise the CCM module.
 */
extern bool lcx_ccm_init (const enum lcx_ccm_mode_datarate datarate,
			  const uint8_t                   *key,
			  const uint8_t                   *iv);

/**
 * Start a encyption/decryption operation.
 *
 * @param[in]  mode Operation mode (encyption/decryption).
 * @param[in]  in   Pointer to the input text.
 * @param[in]  out  Pointer to the output cypher.
 *
 * @retval true  Successfully initiated the encyption/decryption.
 * @retval false Failed to initiate the encryption/decryption.
 */
extern bool lcx_ccm_start (const enum lcx_ccm_mode_mode mode,
			   const uint8_t               *in,
			   const uint8_t               *out);

/**
 * Increment the counter.
 */
extern void lcx_ccm_inc_counter (void);

/* Close C linkage directive for C++: */
#ifdef __cplusplus
}
#endif
